from io import open

from setuptools import find_packages, setup

with open('portainer_py/__init__.py', 'r') as f:
    for line in f:
        if line.startswith('__version__'):
            version = line.strip().split('=')[1].strip(' \'"')
            break
    else:
        version = '0.0.1'

with open('README.rst', 'r', encoding='utf-8') as f:
    readme = f.read()

REQUIRES = ["requests", "click", "colorama"]

setup(
    name='portainer-py',
    version=version,
    description='',
    long_description=readme,
    long_description_content_type='text/x-rst; charset=UTF-8',
    author='Bob Vork',
    author_email='bob@theothersonline.eu',
    maintainer='Bob Vork',
    maintainer_email='bob@theothersonline.eu',
    url='https://github.com/_/portainer-py',
    license='MIT',

    keywords=[
        '',
    ],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],

    install_requires=REQUIRES,
    tests_require=['coverage', 'pytest'],

    packages=find_packages(),
    py_modules=["portainer_py"],
    entry_points="""
    [console_scripts]
    portainerpy=portainer_py.cli:cli
    """
)
